import * as ts from 'typescript';
export interface StringIndexedObject<T> {
    [key: string]: T;
}
export interface ComponentDoc {
    displayName: string;
    description: string;
    props: Props;
}
export interface Props extends StringIndexedObject<PropItem> {
}
export interface PropItem {
    required: boolean;
    type: PropItemType;
    description: string;
    defaultValue: any;
}
export interface PropItemType {
    name: string;
    value?: any;
}
export interface FileParser {
    parse(filePath: string): ComponentDoc[];
}
/**
 * Parses a file with default TS options
 * @param filePath component file that should be parsed
 */
export declare function parse(filePath: string): ComponentDoc[];
/**
 * Constructs a parser for a default configuration.
 */
export declare function withDefaultConfig(): FileParser;
/**
 * Constructs a parser for a specified tsconfig file.
 */
export declare function withCustomConfig(tsconfigPath: string): FileParser;
/**
 * Constructs a parser for a specified set of TS compiler options.
 */
export declare function withCompilerOptions(compilerOptions: ts.CompilerOptions): FileParser;
